@@ -1,15 +1,18 @@
 package Dist::Zilla::PluginBundle::Author::ALEXBIO;
 BEGIN {
-  $Dist::Zilla::PluginBundle::Author::ALEXBIO::VERSION = '0.01';
+  $Dist::Zilla::PluginBundle::Author::ALEXBIO::VERSION = '0.02';
 }
 
 use Moose;
 
 use Dist::Zilla;
+
 use Dist::Zilla::Plugin::Git;
 use Dist::Zilla::Plugin::GitHub;
 use Dist::Zilla::Plugin::ChangelogFromGit;
 
+use Dist::Zilla::Plugin::InstallRelease;
+
 use warnings;
 use strict;
 
@@ -21,7 +24,7 @@ Dist::Zilla::PluginBundle::Author::ALEXBIO - ALEXBIO's default Dist::Zilla confi
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -55,6 +58,9 @@ equivalent to the following:
 
     [Git::Push]
 
+    [InstallRelease]
+    install_command = cpanm .
+
 =cut
 
 sub configure {
@@ -92,6 +98,12 @@ sub configure {
 
 		'Git::Push'
 	);
+
+	$self -> add_plugins(
+		['InstallRelease' => {
+			install_command => 'cpanm .'
+		}]
+	);
 }
 
 =head1 AUTHOR
